@@ -55,6 +55,9 @@ getCambicBounds <- function(p,
                             sandy.texture.pattern = "-S$|^S$|COS$|L[^V]FS$|[^L]VFS$|LS$|LFS$",
                             ...) {
 
+  # sacrafice to CRAN gods in the name of NSE
+  id <- NULL
+  
   # construct data.frame result for no-cambic-found (NA)
   empty_frame <- data.frame(id = character(0),
                             cambic_id = numeric(0),
@@ -144,19 +147,21 @@ getCambicBounds <- function(p,
       }
     }
   }
-  names(final)[1] <- idname(p)
 
   .N <- NULL 
-  iddf <- data.table::data.table(id = as.character(final[[idname(p)]]))[, list(cambic_index = 1:.N), by = "id"]
-  nadf <- data.frame(id = profile_id(p)[!profile_id(p) %in% final[[idname(p)]]])
-  if (!is.null(nadf$id)){
-    nadf[[idname(p)]] <- as.character(nadf$id)
+  iddf <- data.table::data.table(id = as.character(final[["id"]]))[, list(cambic_index = 1:.N), by = "id"]
+  nadf <- data.frame(id = profile_id(p)[!profile_id(p) %in% final[["id"]]])
+  if (nrow(nadf) > 0) {
     nadf$cambic_index <- rep(NA_real_, nrow(nadf))
     nadf$cambic_top <- rep(NA_real_, nrow(nadf))
     nadf$cambic_bottom <- rep(NA_real_, nrow(nadf))
   }
   iddf <- iddf[,-1]
   res <- cbind(final, iddf)
-  res <- data.table::rbindlist(list(res, nadf), fill = TRUE)
+  
+  # note: NSE used to specifiy ordering condition for data.table object
+  # much faster than ordering on the data.frame representation used next
+  res <- data.table::rbindlist(list(res, nadf), fill = TRUE)[order(id)]
+  colnames(res)[1] <- idname(p)
   .as.data.frame.aqp(res, aqp_df_class(p))
 }
