@@ -21,16 +21,20 @@
 #'
 #' # move site data
 #' site(sp1) <- ~ group
-#'
+#' 
+#' # use Munsell color notation as horizon name
+#' sp1$m <- sprintf("%s %s/%s", sp1$hue, sp1$value, sp1$chroma)
+#' 
 #' # compute indices
 #' # merged into `sp1` with left-join on hzidname(sp1)
 #' horizons(sp1) <- horizonColorIndices(sp1, hue="hue", value="value", chroma="chroma")
 #'
 #' # visualize
-#' par(mar=c(0, 1, 3, 1))
-#' plot(sp1, color='hurst_redness')
-#' plot(sp1, color='barron_torrent_redness')
-#' plot(sp1, color='buntley_westin')
+#' par(mar = c(0, 1, 3, 1))
+#' plotSPC(sp1, color='hurst_redness', name = 'm')
+#' plotSPC(sp1, color='barron_torrent_redness', name = 'm')
+#' plotSPC(sp1, color='buntley_westin', name = 'm')
+#' 
 #' @rdname horizonColorIndices
 #' @export horizonColorIndices
 horizonColorIndices <- function(p, hue="m_hue", value="m_value", chroma="m_chroma") {
@@ -65,6 +69,9 @@ hurst.redness <-  function(hue, value, chroma) {
   return(hstar * value / chroma)
 }
 
+
+## TODO for some future time: consider ln(R_{Lab} due to the extreme differences in scale as Munsell value varies by even a single chip)
+
 #' @title Barron & Torrent (1986) Redness Index in LAB color space
 #' @description Calculate Redness Index after Barron & Torrent (1986) "Use of the Kubelka—Munk Theory to Study the Influence of Iron Oxides on Soil Colour" using Munsell colors converted to LAB. DOI: 10.1111/j.1365-2389.1986.tb00382.x. Accepts vectorized inputs for hue, value and chroma, produces vector output.
 #' @param hue A character vector containing Munsell hues (e.g. "7.5YR")
@@ -72,14 +79,15 @@ hurst.redness <-  function(hue, value, chroma) {
 #' @param chroma A numeric vector containing Munsell chromas
 #' @return A numeric vector of horizon redness index (higher values = redder).
 #' @author Andrew G. Brown
-#' @references Barron, V. and Torrent, J. (1986), Use of the Kubelka—Munk theory to study the influence of iron oxides on soil colour. Journal of Soil Science, 37: 499-510. doi:10.1111/j.1365-2389.1986.tb00382.x
+#' @references Barron, V. and Torrent, J. (1986), Use of the Kubelka-Munk theory to study the influence of iron oxides on soil colour. Journal of Soil Science, 37: 499-510. doi:10.1111/j.1365-2389.1986.tb00382.x
 #' @rdname barron.torrent.redness.LAB
 #' @export barron.torrent.redness.LAB
 barron.torrent.redness.LAB <- function(hue, value, chroma) {
-  # after Barron & Torrent (1986) "Use of the Kubelka—Munk Theory to Study the Influence of Iron Oxides on Soil Colour"
+  # after Barron & Torrent (1986) "Use of the Kubelka-Munk Theory to Study the Influence of Iron Oxides on Soil Colour"
   # 10.1111/j.1365-2389.1986.tb00382.x
   lab <- munsell2rgb(hue, value, chroma, returnLAB = TRUE)
-  return(lab$A * sqrt(lab$A^2 + lab$B^2) * 10 ^ 10 / (lab$B * (lab$L ^ 6)))
+  res <- with(lab, (A * sqrt(A^2 + B^2) * 10^10) / (B * L^6))
+  return(res)
 }
 
 #' @title Harden (1982) Rubification
